@@ -12,9 +12,9 @@
 #define FONT_FAMILY     "Arial"
 #define FONT_SIZE       12 // px
 
-#define ELLIPSOID_FILE  QString("ellipsoids.csv")
-#define DATUM_FILE      QString("datums.csv")
-#define MAP_FILE        QString("maps.txt")
+#define ELLIPSOID_FILE  QString("csv/ellipsoids.csv")
+#define GCS_FILE        QString("csv/gcs.csv")
+#define PCS_FILE        QString("csv/pcs.csv")
 #define MAP_DIR         QString("maps")
 #define POI_DIR         QString("POI")
 
@@ -31,15 +31,16 @@
 #endif
 
 #define USER_ELLIPSOID_FILE    USER_DIR + QString("/") + ELLIPSOID_FILE
-#define USER_DATUM_FILE        USER_DIR + QString("/") + DATUM_FILE
+#define USER_GCS_FILE          USER_DIR + QString("/") + GCS_FILE
+#define USER_PCS_FILE          USER_DIR + QString("/") + PCS_FILE
 #define USER_MAP_DIR           USER_DIR + QString("/") + MAP_DIR
-#define USER_MAP_FILE          USER_DIR + QString("/") + MAP_FILE
 #define USER_POI_DIR           USER_DIR + QString("/") + POI_DIR
 #define GLOBAL_ELLIPSOID_FILE  GLOBAL_DIR + QString("/") + ELLIPSOID_FILE
-#define GLOBAL_DATUM_FILE      GLOBAL_DIR + QString("/") + DATUM_FILE
+#define GLOBAL_GCS_FILE        GLOBAL_DIR + QString("/") + GCS_FILE
+#define GLOBAL_PCS_FILE        GLOBAL_DIR + QString("/") + PCS_FILE
 #define GLOBAL_MAP_DIR         GLOBAL_DIR + QString("/") + MAP_DIR
-#define GLOBAL_MAP_FILE        GLOBAL_DIR + QString("/") + MAP_FILE
 #define GLOBAL_POI_DIR         GLOBAL_DIR + QString("/") + POI_DIR
 #define TILES_DIR              USER_DIR + QString("/tiles")
+#define TRANSLATIONS_DIR       GLOBAL_DIR + QString("/translations")
 
 #endif /* CONFIG_H */
